/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2024  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#include <QApplication>
#include <QFrame>
#include <QGridLayout>
#include <QLabel>
#include <QLineEdit>
#include <QSpinBox>
#include <QSpacerItem>
#include <assert.h>

#include "conversionwidget.h"

TConversionWidget::TConversionWidget(
	const QWidget						*parent,
	const Qt::WindowFlags				flags)
:QWidget(const_cast<QWidget*>(parent),flags)
{
	QFrame								*separator_hline1;
	QFrame								*separator_hline2;
	QGridLayout							*widget_layout;
	QLabel								*circular_label;
	QLabel								*current_diameter_label;
	QLabel								*current_length_label;
	QLabel								*filter_width_circular_label;
	QLabel								*filter_width_line_label;
	QLabel								*diameter_units_label;
	QLabel								*circular_width_units_label;
	QLabel								*length_units_label;
	QLabel								*linear_width_units_label;
	QLabel								*line_label;
	QLabel								*undulations_label;
	QSpacerItem							*widget_vspacer;

	widget_layout = new QGridLayout(this);
	widget_layout->setSpacing(4);
	widget_layout->setContentsMargins(4,4,4,4);

	undulations_label = new QLabel(this);
	widget_layout->addWidget(undulations_label,0,0,1,1);

	d_undulations_spin = new QSpinBox(this);
	d_undulations_spin->setAlignment(Qt::AlignCenter);
	d_undulations_spin->setMinimum(1);
	d_undulations_spin->setMaximum(100);
	widget_layout->addWidget(d_undulations_spin,0,1,1,1);

	separator_hline1 = new QFrame(this);
	separator_hline1->setFrameShape(QFrame::HLine);
	separator_hline1->setFrameShadow(QFrame::Sunken);
	widget_layout->addWidget(separator_hline1,1,0,1,3);

	circular_label = new QLabel(this);
	widget_layout->addWidget(circular_label,2,0,1,3);

	current_diameter_label = new QLabel(this);
	current_diameter_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
	widget_layout->addWidget(current_diameter_label,3,0,1,1);

	d_circular_diameter_edit = new QLineEdit(this);
	d_circular_diameter_edit->setAlignment(Qt::AlignCenter);
	d_circular_diameter_edit->setReadOnly(true);
	widget_layout->addWidget(d_circular_diameter_edit,3,1,1,1);

	diameter_units_label = new QLabel(this);
	widget_layout->addWidget(diameter_units_label,3,2,1,1);

	filter_width_circular_label = new QLabel(this);
	filter_width_circular_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
	widget_layout->addWidget(filter_width_circular_label,4,0,1,1);

	d_circular_width_edit = new QLineEdit(this);
	d_circular_width_edit->setAlignment(Qt::AlignCenter);
	d_circular_width_edit->setReadOnly(true);
	widget_layout->addWidget(d_circular_width_edit,4,1,1,1);

	circular_width_units_label = new QLabel(this);
	widget_layout->addWidget(circular_width_units_label,4,2,1,1);

	separator_hline2 = new QFrame(this);
	separator_hline2->setFrameShape(QFrame::HLine);
	separator_hline2->setFrameShadow(QFrame::Sunken);
	widget_layout->addWidget(separator_hline2,5,0,1,3);

	line_label = new QLabel(this);
	widget_layout->addWidget(line_label,6,0,1,3);

	current_length_label = new QLabel(this);
	current_length_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
	widget_layout->addWidget(current_length_label,7,0,1,1);

	d_line_length_edit = new QLineEdit(this);
	d_line_length_edit->setAlignment(Qt::AlignCenter);
	d_line_length_edit->setReadOnly(true);
	widget_layout->addWidget(d_line_length_edit,7,1,1,1);

	length_units_label = new QLabel(this);
	widget_layout->addWidget(length_units_label,7,2,1,1);

	filter_width_line_label = new QLabel(this);
	filter_width_line_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
	widget_layout->addWidget(filter_width_line_label,8,0,1,1);

	d_line_width_edit = new QLineEdit(this);
	d_line_width_edit->setAlignment(Qt::AlignCenter);
	d_line_width_edit->setReadOnly(true);
	widget_layout->addWidget(d_line_width_edit,8,1,1,1);
	
	linear_width_units_label = new QLabel(this);
	widget_layout->addWidget(linear_width_units_label,8,2,1,1);

	widget_vspacer = new QSpacerItem(0,0,QSizePolicy::Minimum,QSizePolicy::Expanding);
	widget_layout->addItem(widget_vspacer,9,0,1,3);


	QWidget::setTabOrder(d_undulations_spin,d_circular_diameter_edit);
	QWidget::setTabOrder(d_circular_diameter_edit,d_circular_width_edit);
	QWidget::setTabOrder(d_circular_width_edit,d_line_length_edit);
	QWidget::setTabOrder(d_line_length_edit,d_line_width_edit);
	
	// defaults
	d_undulations_spin->setValue(10);
	d_circular_diameter_edit->setText(QStringLiteral("25.0000"));
	d_circular_width_edit->setText(QStringLiteral("7.8540"));
	d_line_length_edit->setText(QStringLiteral("100.0000"));
	d_line_width_edit->setText(QStringLiteral("10.0000"));

	undulations_label->setText(QStringLiteral("Undulations Value:"));
	circular_label->setText(QStringLiteral("Circle / Cylinder"));
	current_diameter_label->setText(QStringLiteral("Current Diameter:"));
	filter_width_circular_label->setText(QStringLiteral("Filter Width:"));
	line_label->setText(QStringLiteral("Line"));
	current_length_label->setText(QStringLiteral("Current Length:"));
	filter_width_line_label->setText(QStringLiteral("Filter Width:"));
	diameter_units_label->setText(QStringLiteral("mm"));
	circular_width_units_label->setText(QStringLiteral("mm"));
	length_units_label->setText(QStringLiteral("mm"));
	linear_width_units_label->setText(QStringLiteral("mm"));
	
	connect(d_undulations_spin,static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged),this,&TConversionWidget::Undulations_Changed);
}

TConversionWidget::~TConversionWidget(void)
{
}

void TConversionWidget::Set_Circular_Diameter(
	const double 						&diameter)
{
	int									undulations;
	double								length;
	double								width;
	static const double					PI2(6.283185307179586);
	
	undulations = d_undulations_spin->value();	
	assert(undulations > 0);
	
	length = PI2 * (diameter / 2.0);
	width = length / static_cast<double>(undulations);
	
	d_circular_diameter_edit->setText(QString("%1").arg(diameter,0,'f',4));
	d_circular_width_edit->setText(QString("%1").arg(width,0,'f',4));
}

void TConversionWidget::Set_Linear_Length(
	const double 						&length)
{
	double								width;
	int									undulations;

	undulations = d_undulations_spin->value();	
	assert(undulations > 0);

	width = length / static_cast<double>(undulations);
	
	d_line_length_edit->setText(QString("%1").arg(length,0,'f',4));
	d_line_width_edit->setText(QString("%1").arg(width,0,'f',4));
}

void TConversionWidget::Undulations_Changed(void)
{
	double								diameter;
	double								length;
	
	diameter = d_circular_diameter_edit->text().toDouble();
	length = d_line_length_edit->text().toDouble();
	
	this->Set_Circular_Diameter(diameter);
	this->Set_Linear_Length(length);
}

