/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2024  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#include <QApplication>
#include <QGridLayout>
#include <QLabel>
#include <QLineEdit>
#include <QSpacerItem>

#include "exportimportwidget.h"

TExportImportWidget::TExportImportWidget(
	const QWidget						*parent,
	const Qt::WindowFlags				flags)
:QWidget(const_cast<QWidget*>(parent),flags)
{
	QGridLayout							*widget_layout;
	QLabel								*export_signal_size_label;
	QLabel								*import_signal_size_label;
	QSpacerItem							*widget_vspacer;

	widget_layout = new QGridLayout(this);
	widget_layout->setSpacing(4);
	widget_layout->setContentsMargins(4,4,4,4);

	export_signal_size_label = new QLabel(this);
	export_signal_size_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
	widget_layout->addWidget(export_signal_size_label,0,0,1,1);

	d_export_signal_size_edit = new QLineEdit(this);
	d_export_signal_size_edit->setAlignment(Qt::AlignCenter);
	d_export_signal_size_edit->setReadOnly(true);
	widget_layout->addWidget(d_export_signal_size_edit,0,1,1,1);

	import_signal_size_label = new QLabel(this);
	import_signal_size_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
	widget_layout->addWidget(import_signal_size_label,1,0,1,1);

	d_import_signal_size_edit = new QLineEdit(this);
	d_import_signal_size_edit->setAlignment(Qt::AlignCenter);
	d_import_signal_size_edit->setReadOnly(true);
	widget_layout->addWidget(d_import_signal_size_edit,1,1,1,1);

	widget_vspacer = new QSpacerItem(0,0,QSizePolicy::Minimum,QSizePolicy::Expanding);
	widget_layout->addItem(widget_vspacer,2,0,1,2);

	export_signal_size_label->setText(QStringLiteral("Generated Sample Size:"));
	import_signal_size_label->setText(QStringLiteral("Imported Sample Size:"));
}

TExportImportWidget::~TExportImportWidget(void)
{
}

void TExportImportWidget::Set_Export_Size(
	const int 							size)
{
	d_export_signal_size_edit->setText(QString("%1").arg(size));
}

void TExportImportWidget::Set_Import_Size(
	const int 							size)
{
	d_import_signal_size_edit->setText(QString("%1").arg(size));
}
