/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2024  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#include <QApplication>
#include <QGridLayout>
#include <QLabel>
#include <QLineEdit>
#include <QSpinBox>
#include <QSpacerItem>

#include "featurecylinderwidget.h"

TFeatureCylinderWidget::TFeatureCylinderWidget(
	const QWidget						*parent,
	const Qt::WindowFlags				flags)
:QWidget(const_cast<QWidget*>(parent),flags)
{
	QGridLayout							*widget_layout;
	QLabel								*diameter_label;
	QLabel								*diameter_units_label;
	QLabel								*length_label;
	QLabel								*length_units_label;
	QLabel								*levels_label;
	QSpacerItem							*widget_vspacer;

	widget_layout = new QGridLayout(this);
	widget_layout->setSpacing(4);
	widget_layout->setContentsMargins(4,4,4,4);

	diameter_label = new QLabel(this);
	widget_layout->addWidget(diameter_label,0,0,1,1);

	d_diameter_edit = new QLineEdit(this);
	d_diameter_edit->setAlignment(Qt::AlignCenter);
	widget_layout->addWidget(d_diameter_edit,0,1,1,1);

	diameter_units_label = new QLabel(this);
	widget_layout->addWidget(diameter_units_label,0,2,1,1);

	length_label = new QLabel(this);
	widget_layout->addWidget(length_label,1,0,1,1);

	d_length_edit = new QLineEdit(this);
	d_length_edit->setAlignment(Qt::AlignCenter);
	widget_layout->addWidget(d_length_edit,1,1,1,1);

	length_units_label = new QLabel(this);
	widget_layout->addWidget(length_units_label,1,2,1,1);

	levels_label = new QLabel(this);
	widget_layout->addWidget(levels_label,2,0,1,1);

	d_levels_spin = new QSpinBox(this);
	d_levels_spin->setAlignment(Qt::AlignCenter);
	d_levels_spin->setMinimum(2);
	widget_layout->addWidget(d_levels_spin,2,1,1,1);
	
	widget_vspacer = new QSpacerItem(0,0,QSizePolicy::Minimum,QSizePolicy::Expanding);
	widget_layout->addItem(widget_vspacer,3,0,1,3);
	
	// defaults
	d_levels_spin->setValue(2);
	d_diameter_edit->setText(QStringLiteral("25.0000"));
	d_length_edit->setText(QStringLiteral("50.0000"));

	diameter_label->setText(QStringLiteral("Diameter:"));
	diameter_units_label->setText(QStringLiteral("mm"));
	length_label->setText(QStringLiteral("Length:"));
	length_units_label->setText(QStringLiteral("mm"));
	levels_label->setText(QStringLiteral("Levels:"));
	
	connect(d_diameter_edit,&QLineEdit::editingFinished,this,&TFeatureCylinderWidget::Data_Changed);
	connect(d_length_edit,&QLineEdit::editingFinished,this,&TFeatureCylinderWidget::Data_Changed);
	connect(d_levels_spin,static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged),this,&TFeatureCylinderWidget::Data_Changed);
}

TFeatureCylinderWidget::~TFeatureCylinderWidget(void)
{
}

double TFeatureCylinderWidget::Diameter(void) const
{
	return d_diameter_edit->text().toDouble();
}

double TFeatureCylinderWidget::Length(void) const
{
	return d_length_edit->text().toDouble();
}

int TFeatureCylinderWidget::Levels(void) const
{
	return d_levels_spin->value();
}

void TFeatureCylinderWidget::Set_Diameter(
	const double 						&d)
{
	d_diameter_edit->setText(QString("%1").arg(d,0,'f',4));
}

void TFeatureCylinderWidget::Set_Length(
	const double 						&d)
{
	d_length_edit->setText(QString("%1").arg(d,0,'f',4));
}

void TFeatureCylinderWidget::Set_Levels(
	const int 							i)
{
	d_levels_spin->setValue(i);
}


