/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2024  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#include <QApplication>
#include <QGridLayout>
#include <QLabel>
#include <QLineEdit>
#include <QSpacerItem>

#include "featurelinewidget.h"

TFeatureLineWidget::TFeatureLineWidget(
	const QWidget						*parent,
	const Qt::WindowFlags				flags)
:QWidget(const_cast<QWidget*>(parent),flags)
{
	QGridLayout							*widget_layout;
	QLabel								*length_label;
	QLabel								*length_units_label;
	QSpacerItem							*widget_vspacer;

	widget_layout = new QGridLayout(this);
	widget_layout->setSpacing(4);
	widget_layout->setContentsMargins(4,4,4,4);

	length_label = new QLabel(this);
	widget_layout->addWidget(length_label,0,0,1,1);

	d_length_edit = new QLineEdit(this);
	d_length_edit->setAlignment(Qt::AlignCenter);
	widget_layout->addWidget(d_length_edit,0,1,1,1);

	length_units_label = new QLabel(this);
	widget_layout->addWidget(length_units_label,0,2,1,1);

	widget_vspacer = new QSpacerItem(0,0,QSizePolicy::Minimum,QSizePolicy::Expanding);
	widget_layout->addItem(widget_vspacer,1,0,1,3);
	
	// defaults
	d_length_edit->setText(QStringLiteral("100.0000"));

	length_label->setText(QStringLiteral("Length:"));
	length_units_label->setText(QStringLiteral("mm"));
	
	connect(d_length_edit,&QLineEdit::editingFinished,this,&TFeatureLineWidget::Data_Changed);
	
}

TFeatureLineWidget::~TFeatureLineWidget(void)
{
}

double TFeatureLineWidget::Length(void) const
{
	return d_length_edit->text().toDouble();
}

void TFeatureLineWidget::Set_Length(
	const double 						&d)
{
	d_length_edit->setText(QString("%1").arg(d,0,'f',4));
}
