/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2024  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#ifndef FEATUREWIDGETHEADERFILE
#define FEATUREWIDGETHEADERFILE

#include <QWidget>

#include "../../core/vector3.h"

class QLineEdit;
class QTabWidget;

class TFeatureCircleWidget;
class TFeatureCylinderWidget;
class TFeatureLineWidget;
class TXmlFile;

class TFeatureWidget : public QWidget
{
Q_OBJECT

public:
	
enum TFeatureType
{
	FEATURE_CIRCLE = 0,
	FEATURE_CYLINDER,
	FEATURE_LINE
};


// CREATORS
	TFeatureWidget(const QWidget *parent=0, Qt::WindowFlags flags=Qt::WindowFlags());
	~TFeatureWidget(void);

// ACCESSORS
	QString Last_Error(void) const {return d_last_error;}
	bool Save_Data(const QString &data_path) const;

	TVector3 Position(void) const;
	TVector3 Orientation(void) const;
	
	TFeatureType Active_Feature_Type(void) const;
	
	double Feature_Circle_Diameter(void) const;
	double Feature_Cylinder_Diameter(void) const;
	double Feature_Cylinder_Length(void) const;
	int Feature_Cylinder_Levels(void) const;
	double Feature_Line_Length(void) const;

// MANIPULATORS
	bool Load_Data(const QString &data_path);
	
	void Set_Position(const TVector3 &pos);
	void Set_Orientation(const TVector3 &vec);
	
	void Set_Active_Feature_Type(const TFeatureType type);
	
	void Set_Feature_Circle_Diameter(const double &d);
	void Set_Feature_Cylinder_Diameter(const double &d);
	void Set_Feature_Cylinder_Length(const double &d);
	void Set_Feature_Cylinder_Levels(const int i);
	void Set_Feature_Line_Length(const double &d);

signals:
	void Feature_Updated(void);

private slots:
	void Feature_Modified(void);

private:
	QLineEdit							*d_orientation_i_edit;
	QLineEdit							*d_orientation_j_edit;
	QLineEdit							*d_orientation_k_edit;
	QLineEdit							*d_position_x_edit;
	QLineEdit							*d_position_y_edit;
	QLineEdit							*d_position_z_edit;
	QTabWidget							*d_feature_type_tab;
	TFeatureCircleWidget				*d_feature_circle_widget;
	TFeatureCylinderWidget				*d_feature_cylinder_widget;
	TFeatureLineWidget					*d_feature_line_widget;
	
	mutable QString						d_last_error;
	mutable bool						d_data_changed;

	bool Save(const QString &data_path) const;
	void Load_Version1(TXmlFile * const xml_file);

// NOT IMPLEMENTED
	TFeatureWidget(const TFeatureWidget&);
	TFeatureWidget& operator=(const TFeatureWidget&);
};

#endif
