/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2024  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////



#ifndef FILTEREVALUATIONHEADERFILE
#define FILTEREVALUATIONHEADERFILE

#include <QMainWindow>
#include <vector>

#include "../../core/vector2.h"

class QAction;
class QSettings;
class QCloseEvent;
class QTabWidget;

class TMessageBox;
class TGraphWidget;
class TFeatureWidget;
class TParameterSettingsWidget;
class TConversionWidget;
class TExportImportWidget;

class TFilterEvaluation : public QMainWindow
{
Q_OBJECT

public:

// CREATORS
	TFilterEvaluation(const QWidget *parent=0, Qt::WindowFlags flags=Qt::WindowFlags());
	virtual ~TFilterEvaluation(void);

// ACCESSORS

// MANIPULATORS

signals:

private slots:
	void Graph_Bar(void);
	void Graph_Line(void);
	void Graph_Point(void);
	void Graph_Scale_To_Fit(void);
	
	void Update_Signal(void);
	void Write_Signal(void);
	void Write_DMIS(void);
	void Import_Signal_Data(void);
	void Help_About(void);
	
	void View_Changed(int);
	void Sub_View_Changed(int);
	
protected:
	virtual void closeEvent(QCloseEvent *event);

private:

enum TSignalType
{
	UNKNOWN_TYPE = 0,
	CIRCLE_SIGNAL,
	LINE_SIGNAL
	
};
	
	QAction								*d_action_export_signal;
	QAction								*d_action_export_dmis;
	QAction								*d_action_graph_bar;
	QAction								*d_action_graph_line;
	QAction								*d_action_graph_point;
	QTabWidget							*d_graph_tab;
	QTabWidget							*d_generated_views_tab;
	QTabWidget							*d_imported_views_tab;
	TGraphWidget						*d_generated_signal_graph_widget;
	TGraphWidget						*d_imported_signal_graph_widget;
	TGraphWidget						*d_generated_wave_graph_widget;
	TGraphWidget						*d_imported_wave_graph_widget;
	TFeatureWidget						*d_feature_widget;
	TParameterSettingsWidget			*d_parameters_settings_widget;
	TConversionWidget					*d_conversion_widget;
	TExportImportWidget					*d_export_import_widget;
	TMessageBox							*d_msg_box;

	QSettings							*d_settings;
	QString								d_application_path;
	QString								d_data_path;
	QString								d_file_path;

	std::vector<TVector2>				d_signal_data;
	
	mutable QString						d_last_error;
	
	double Get_Max_Value(const std::vector<TVector2> &data) const;
	void Normalize(std::vector<TVector2> * const data,const double &max,const double &range) const;
	std::vector<TVector2> Normalize_Signal_Data(const std::vector<TVector2> &signal_data) const;
	void Get_Sub_Points(const TVector2 &p1,const TVector2 &p2,const TVector2 &p3,TVector2 * const first_pt,TVector2 * const second_pt) const;
	
	void Convert_To_Undulations(std::vector<TVector2> * const data) const;
	double Convert_Frequency_To_Undulations(const int data_size,const double &frequency) const;
	int Get_Minimum_Sample_Size(const int max_undulations) const;
	int Get_Sample_Window_Size(const int data_size) const;

	void Write_DMIS_Circle(const QString &file_name) const;
	void Write_DMIS_Cylinder(const QString &file_name) const;
	void Write_DMIS_Line(const QString &file_name) const;
	
	void Write_Signal_Circle(const QString &file_name) const;
	void Write_Signal_Line(const QString &file_name) const;

	std::vector<TVector2> Read_Signal_File(const QString &file_name,bool * const valid,TSignalType * const signal_type,double * const range) const;

	void Add_Signal_Entry(const int undulations,const double &phase,const double &amplitude);

// NOT IMPLEMENTED
	TFilterEvaluation(const TFilterEvaluation&);
	TFilterEvaluation& operator=(const TFilterEvaluation&);
};

#endif
