/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2024  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#ifndef PARAMETERDIALOGHEADERFILE
#define PARAMETERDIALOGHEADERFILE

#include <QDialog>

class QDoubleSpinBox;
class QSpinBox;
class QPushButton;

class TParameterDialog : public QDialog
{
Q_OBJECT

public:
	
enum TMode
{
	MODE_ADD = 0,
	MODE_EDIT,
	MODE_MULTI_EDIT
};

// CREATORS
	TParameterDialog(const QWidget *parent=0, Qt::WindowFlags flags=Qt::WindowFlags());
	~TParameterDialog(void);

// ACCESSORS
	double Amplitude(void) const;
	double Phase(void) const;
	int Undulations(void) const;

// MANIPULATORS
	void Reset(const TMode mode);
	void Set_Amplitude(const double &value);
	void Set_Phase(const double &value);
	void Set_Undulations(const int value);

signals:
	void Add_Signal_Entry(const int undulations,const double &phase,const double &amplitude);

private slots:
	void Accept(void);

private:
	QDoubleSpinBox						*d_amplitude_spin;
	QDoubleSpinBox						*d_phase_spin;
	QSpinBox							*d_undulations_spin;
	QPushButton							*d_accept_button;
	QPushButton							*d_cancel_button;
	TMode								d_current_mode;

// NOT IMPLEMENTED
	TParameterDialog(const TParameterDialog&);
	TParameterDialog& operator=(const TParameterDialog&);
};

#endif
