/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2024  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////



#ifndef PARAMETERSETTINGSWIDGETHEADERFILE
#define PARAMETERSETTINGSWIDGETHEADERFILE

#include <QWidget>
#include <vector>

class QListWidget;
class QToolButton;
class QSpinBox;

class TParameterDialog;
class TXmlFile;

class TParameterSettingsWidget : public QWidget
{
Q_OBJECT

public:
	
struct TEntryItem
{
	double								amplitude;
	double								phase;
	int									undulations;
	
	bool operator<(const TEntryItem item) {return this->undulations < item.undulations;}
};

// CREATORS
	TParameterSettingsWidget(const QWidget *parent=0, Qt::WindowFlags flags=Qt::WindowFlags());
	~TParameterSettingsWidget(void);

// ACCESSORS
	QString Last_Error(void) const {return d_last_error;}
	bool Save_Data(const QString &data_path) const;

	std::vector<TEntryItem> Entry_Items(void) const {return d_entry_items;}
	
	int Maximum_Undulations(void) const;
	double Maximum_Amplitude(void) const;
	
	int Modulation(void) const;


// MANIPULATORS
	bool Load_Data(const QString &data_path);
	
	void Set_Modulation(const int ival);

	
signals:
	void Parameters_Changed(void);

private slots:
	void Add_Entry(void);
	void Remove_Entries(void);
	void Edit_Entry(void);
	void Entry_Selection_Changed(void);
	
	void Add_Signal_Entry(const int undulations,const double &phase,const double &amplitude);
	

private:
	
	QSpinBox							*d_modulation_spin;
	QListWidget							*d_entries_list;
	QToolButton							*d_add_button;
	QToolButton							*d_edit_button;
	QToolButton							*d_remove_button;
	TParameterDialog					*d_parameter_dialog;
	
	std::vector<TEntryItem>				d_entry_items;
	
	mutable bool						d_data_changed;
	mutable QString						d_last_error;
	
	void Generate_Test_Data(void);
	
	void Update_Entry_Items_From_List(void);
	void Update_List_From_Entry_Items(void);
	
	bool Save(const QString &data_path) const;
	void Load_Version1(TXmlFile * const xml_file);


// NOT IMPLEMENTED
	TParameterSettingsWidget(const TParameterSettingsWidget&);
	TParameterSettingsWidget& operator=(const TParameterSettingsWidget&);
};

#endif
